==> tenant-domain-1.0.76-20200417.043927-1-sources.jar: com/xforceplus/domain/settle/SettleFlowDto.java <==
package com.xforceplus.domain.settle;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.core.type.TypeReference;
import com.xforceplus.domain.resource.ServicePackageDto;
import io.geewit.web.utils.JsonUtils;

import javax.persistence.Transient;
import java.util.List;
import java.util.Map;
import java.util.Objects;

public class SettleFlowDto<T extends SettleTemplateDto<A>, A extends SettleTemplateAttributeDto> {
    protected Long flowId;
    protected String flowCode;
    protected String flowName;
    protected Long tenantId;
    protected String tenantCode;
    protected String rawProperties;
    protected String script;

    protected List<T> templates;
    protected List<Long> packageIds;

    public Long getFlowId() {
        return flowId;
    }

    public void setFlowId(Long flowId) {
        this.flowId = flowId;
    }

    public String getFlowCode() {
        return flowCode;
    }

    public void setFlowCode(String flowCode) {
        this.flowCode = flowCode;
    }

    public String getFlowName() {
        return flowName;
    }

    public void setFlowName(String flowName) {
        this.flowName = flowName;
    }

    public Long getTenantId() {
        return tenantId;
    }

    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }

    public String getTenantCode() {
        return tenantCode;
    }

    public void setTenantCode(String tenantCode) {
        this.tenantCode = tenantCode;
    }

    @JsonIgnore
    public String getRawProperties() {
        return rawProperties;
    }

    public void setRawProperties(String rawProperties) {
        this.rawProperties = rawProperties;
    }

    public String getScript() {
        return script;
    }

    public void setScript(String script) {
        this.script = script;
    }

    @Transient
    public List<Long> getPackageIds() {
        return packageIds;
    }

    public void setPackageIds(List<Long> packageIds) {
        this.packageIds = packageIds;
    }

    public List<T> getTemplates() {
        return templates;
    }

    public void setTemplates(List<T> templates) {
        this.templates = templates;
    }

    @Transient
    public Map<String, Object> getProperties() {
        if (this.rawProperties != null) {
            try {
                Map<String, Object> properties = JsonUtils.fromJson(this.rawProperties, new TypeReference<Map<String, Object>>() {
                });
                return properties;
            } catch (Exception e) {
            }
        }
        return null;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SettleFlowDto that = (SettleFlowDto) o;
        return Objects.equals(flowId, that.flowId);
    }

    @Override
    public int hashCode() {
        return Objects.hash(flowId);
    }

    @Override
    public String toString() {
        return "SettleFlowDto{" +
                "flowId=" + flowId +
                ", flowName='" + flowName + '\'' +
                ", tenantId=" + tenantId +
                ", tenantCode='" + tenantCode + '\'' +
                ", rawProperties='" + rawProperties + '\'' +
                ", script='" + script + '\'' +
                '}';
    }
}

==> tenant-domain-1.1.10-20200527.054944-8-sources.jar: com/xforceplus/domain/settle/SettleFlowDto.java <==
package com.xforceplus.domain.settle;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.core.type.TypeReference;
import com.xforceplus.domain.resource.ServicePackageDto;
import io.geewit.web.utils.JsonUtils;

import javax.persistence.Transient;
import java.util.List;
import java.util.Map;
import java.util.Objects;

public class SettleFlowDto<T extends SettleTemplateDto<A>, A extends SettleTemplateAttributeDto> {
    protected Long flowId;
    protected String flowCode;
    protected String flowName;
    protected Long tenantId;
    protected String tenantCode;

    public List<SettleStepDto> getSettleStep() {
        return settleStep;
    }

    public void setSettleStep(List<SettleStepDto> settleStep) {
        this.settleStep = settleStep;
    }

    protected List<SettleStepDto> settleStep;
    protected String rawProperties;
    protected String script;
    protected List<T> templates;
    protected List<Long> packageIds;




    public Long getFlowId() {
        return flowId;
    }

    public void setFlowId(Long flowId) {
        this.flowId = flowId;
    }

    public String getFlowCode() {
        return flowCode;
    }

    public void setFlowCode(String flowCode) {
        this.flowCode = flowCode;
    }

    public String getFlowName() {
        return flowName;
    }

    public void setFlowName(String flowName) {
        this.flowName = flowName;
    }

    public Long getTenantId() {
        return tenantId;
    }

    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }

    public String getTenantCode() {
        return tenantCode;
    }

    public void setTenantCode(String tenantCode) {
        this.tenantCode = tenantCode;
    }

    @JsonIgnore
    public String getRawProperties() {
        return rawProperties;
    }

    public void setRawProperties(String rawProperties) {
        this.rawProperties = rawProperties;
    }

    public String getScript() {
        return script;
    }

    public void setScript(String script) {
        this.script = script;
    }

    @Transient
    public List<Long> getPackageIds() {
        return packageIds;
    }

    public void setPackageIds(List<Long> packageIds) {
        this.packageIds = packageIds;
    }

    public List<T> getTemplates() {
        return templates;
    }

    public void setTemplates(List<T> templates) {
        this.templates = templates;
    }

    @Transient
    public Map<String, Object> getProperties() {
        if (this.rawProperties != null) {
            try {
                Map<String, Object> properties = JsonUtils.fromJson(this.rawProperties, new TypeReference<Map<String, Object>>() {
                });
                return properties;
            } catch (Exception e) {
            }
        }
        return null;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SettleFlowDto that = (SettleFlowDto) o;
        return Objects.equals(flowId, that.flowId);
    }

    @Override
    public int hashCode() {
        return Objects.hash(flowId);
    }

    @Override
    public String toString() {
        return "SettleFlowDto{" +
                "flowId=" + flowId +
                ", flowName='" + flowName + '\'' +
                ", tenantId=" + tenantId +
                ", tenantCode='" + tenantCode + '\'' +
                ", rawProperties='" + rawProperties + '\'' +
                ", script='" + script + '\'' +
                '}';
    }
}
